;======================== header ===============================================
;+
; NAME:
;       SOFAST_MAKE_EVENTMOVIE 
;
; PURPOSE:
;		Is called by sofast.pro  (or sofast_swaplocal.pro or sofast_WGET_local.pro)
;       First exclude unwanted images (offpointed, blurred, eclipsed); 
;		Apply to allfiles (structure)
;       Create eventmovie: 
;		eventmovie[*,*,j] = (rebin(abs(a - b) - offset > 0.1, rebinsize, rebinsize) <255)
;		with b 12minutes prior to a; 
;
; INPUT
;		begindate, enddate = '2011-01-04'
;		allfiles=allfiles (STRUCTURE from p2_getswapfilenames, incl url, obsdate, tags like sisterurl, etc.)
;		savdir=savdir (where to save *.sav files)
;		eventdir=eventdir (where to save event info)
;
;		VALUES KNOWN FROM SOFAST.PRO:
;		timedif=timedif (time accepted between images a and b, e.g. 12min)
;		timetol=timetol (tolerance on timedif, e.g. 2min)
;		rebinsize=rebinsize (e.g. 16)
;		xwidth=xwidth (e.g. 1024), ywidth=ywidth (e.g. 1024)
;		offset=offset (first kind of thresholding, estimate for excluding solar activity from quiet Sun)
;		to be saved: first_SWAP_thisrun_final=first_SWAP_thisrun_final, last_SWAP_thisrun_final=last_SWAP_thisrun_final
;		eclipse_notification=eclipse_notification
;
; PROCEDURES USED:
;		readfits
;		sofast_blurfilter_loop
;
; RESTORED SAV-files:
;		/
;
; SAVED SAV-files:
;		save, filename = savdir+'timeline_maxima_thismacropixel_X'+strtrim(x,2)+'_Y'+strtrim(y,2)+'.sav', timeline_maxima_thismacropixel
;						(CONTAINS max of timeline of XY-macropixel, derived on pixel level before rebinning)
;		save, filename = savdir+'timeline_minima_thismacropixel_X'+strtrim(x,2)+'_Y'+strtrim(y,2)+'.sav', timeline_minima_thismacropixel
;						(CONTAINS min of timeline of XY-macropixel, derived on pixel level before rebinning)
;		save, filename = savdir+'macropixel_int_X'+strtrim(x,2)+'_Y'+strtrim(y,2)+'.sav', macropixel_int
;						(CONTAINS timeline of XY-macropixel, rebinned intensity in time)
;		UNCOMMENTED: save, filename = savdir+'rebinned_images.sav', images ; 	
;						(CONTAINS images[*,*,*] = rebin(a, rebinsize,rebinsize) ).
;		UNCOMMENTED: save, filename = savdir+'eventmovie.sav', eventmovie
;						(CONTAINS eventmovie = byte array in the sence of (rebin(abs(a - b) - offset > 0.1, rebinsize, rebinsize) <255)    )
;
; HISTORY:  
;		2012 Dec 12, KB, update to final SoFAST version 
;-
;======================== end header ===========================================

FUNCTION sofast_make_eventmovie, begindate=begindate, enddate=enddate, allfiles=allfiles, savdir=savdir, eventdir=eventdir, timedif=timedif, timetol=timetol, rebinsize=rebinsize, xwidth=xwidth, ywidth=ywidth, offset=offset, first_SWAP_thisrun_final=first_SWAP_thisrun_final, last_SWAP_thisrun_final=last_SWAP_thisrun_final, eclipse_notification=eclipse_notification, totalNr_images=totalNr_images, nr_good_images=nr_good_images

; allfiles is structure of ALL files from begindate to enddate (before excluding offpointed, blurred and eclipsed images)


allfiles_start = allfiles
nfiles_start = n_elements(allfiles_start)

eventmovie = bytarr(rebinsize, rebinsize, nfiles_start) ; initializing dimension, later redefined.

notification = '    '
note_offp = '    '
note_blur = '    '
note_eclipse = '    '

print, 'nfiles_start = ', nfiles_start
totalNr_images = nfiles_start

IF nfiles_start gt 1 THEN BEGIN  ; IF NO IMAGES THEN ALLFILES = 0 (n_elements=1)XXXXXXX line 304  

	; INCLUSIVE FILTERING OUT OF OFFPOINTED IMAGES (KB, 23052011):
	mreadfits, allfiles_start.url, indexallfiles_start, /nodata ; reading headers only
	print, 'sofast_make_eventmovie: finished readfits allfiles_start /nodata for excluding offpointed images'
	
	first_SWAP_thisrun_start = indexallfiles_start[0].filename ; if no valid SWAP files were found, first and last SWAP_thisrun will be the same ([0])
	last_SWAP_thisrun_start = indexallfiles_start[n_elements(indexallfiles_start)-1].filename
	
	
	 ; EXCLUDE OFFPOINTED IMAGES
	FOR k=0, nfiles_start-1 DO BEGIN 
	 	IF  (indexallfiles_start[k].pav_rot0 ne 0.0 or indexallfiles_start[k].pav_rot1 ne 0.0) THEN BEGIN
	 		allfiles_start[k].quality = 'offpointed'
	 	ENDIF ELSE BEGIN
	 		allfiles_start[k].quality = 'not-offpointed'
	 	ENDELSE
	ENDFOR
	
	w_notoffpointed = where(allfiles_start.quality eq 'not-offpointed', n_notoffpointed)
	IF n_notoffpointed gt 0 THEN BEGIN
		IF n_notoffpointed eq nfiles_start THEN BEGIN
			allfiles_notoffpointed = allfiles_start 
			indexallfiles_notoffpointed = indexallfiles_start	
			note_offp = 'There are no offpointed images for this run'
		ENDIF ELSE BEGIN
			allfiles_notoffpointed = allfiles_start[w_notoffpointed] 
			indexallfiles_notoffpointed = indexallfiles_start[w_notoffpointed]
		ENDELSE
	 
		; EXCLUDE BLURRED IMAGES
		nfiles_notoffpointed = n_elements(allfiles_notoffpointed)
		FOR i=0, nfiles_notoffpointed-1 DO BEGIN
			image = readfits(allfiles_notoffpointed[i].url)
			print, 'sofast_make_eventmovie: readfits allfiles_notoffpointed for then applying sofast_blurfilter_loop '+strtrim(i,2)
			where_notblur = sofast_blurfilter_loop(image, savdir, i=i) ; returns <where...> 
			IF where_notblur eq 1 then begin
				allfiles_notoffpointed[i].bluriness = 'notblur'
			ENDIF ELSE BEGIN
				allfiles_notoffpointed[i].bluriness = 'blur'
			ENDELSE
		ENDFOR
		
		w_notblur = where(allfiles_notoffpointed.bluriness eq 'notblur', n_notblur)
		IF n_notblur gt 0 THEN BEGIN
			IF n_notblur eq nfiles_notoffpointed THEN BEGIN
	 			allfiles_notblur = allfiles_notoffpointed 
				indexallfiles_notblur = indexallfiles_notoffpointed 
				note_blur = 'There are no blur images for this run'
	 		ENDIF ELSE BEGIN
	 			allfiles_notblur = allfiles_notoffpointed[w_notblur] 
				indexallfiles_notblur = indexallfiles_notoffpointed[w_notblur] 
			ENDELSE
	
	
			; EXCLUDE OFFPOINTED IMAGES
			nfiles_notblur = n_elements(allfiles_notblur)
			FOR k=0, nfiles_notblur-1 DO BEGIN 
	 			IF indexallfiles_notblur[k].LOS_ALT lt 700 THEN BEGIN ; 700000 is too strict, 350000 based on trial and error
	 				allfiles_notblur[k].eclipse = 'eclipsed'
	 			ENDIF ELSE BEGIN
	 				allfiles_notblur[k].eclipse = 'noteclipsed'			
	 			ENDELSE
			ENDFOR
	
			w_noteclipsed = where(allfiles_notblur.eclipse eq 'noteclipsed', n_noteclipsed)
			IF n_noteclipsed gt 0 THEN BEGIN ; first this was gt 0, but we now accept some images eclipsed for not giving the eclipse message all the time
				IF n_noteclipsed eq n_notblur THEN BEGIN
					allfiles_noteclipsed = allfiles_notblur[w_noteclipsed]
					indexallfiles_noteclipsed = indexallfiles_notblur[w_noteclipsed]
					note_eclipse = 'There are no eclipsed images for this run'
				ENDIF ELSE BEGIN
					allfiles_noteclipsed = allfiles_notblur[w_noteclipsed]
					indexallfiles_noteclipsed = indexallfiles_notblur[w_noteclipsed]
	 			ENDELSE
	 				
	 				allfiles = allfiles_noteclipsed
	 				indexallfiles = indexallfiles_noteclipsed
	 
					first_SWAP_thisrun_final = indexallfiles[0].filename ; if no valid SWAP files were found, first and last SWAP_thisrun will be the same ([0])
					last_SWAP_thisrun_final = indexallfiles[n_elements(indexallfiles)-1].filename
				
			ENDIF ELSE BEGIN
				notification = '!! ALL INPUT IMAGES ARE OFFPOINTED and/or BLUR and/or ECLIPSED !!'
				print, notification
	 			allfiles = allfiles_notblur[0] ; keep 1 element in allfiles to feed to sofast_region_plotter.pro + keep track of offp/blur/eclipsed
	 			indexallfiles = indexallfiles_notblur[0] ; keep 1 element in allfiles to feed to sofast_region_plotter.pro + keep track of offp/blur/eclipsed
	
				allfiles.quality='offpointed'
				allfiles.bluriness='blur'
				allfiles.eclipse='eclipsed'
				allfiles_noteclipsed = allfiles
				
			ENDELSE
	
	 
	; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX 
	
		ENDIF ELSE BEGIN    ;    IF n_elements(notblur) gt 1 THEN BEGIN
			notification = '!! ALL INPUT IMAGES ARE OFFPOINTED and/or BLUR !!'
	 		print, notification
	 		allfiles = allfiles_notoffpointed[0] ; keep 1 element in allfiles to feed to sofast_region_plotter.pro + keep track of offp/blur/eclipsed
			indexallfiles = indexallfiles_notoffpointed[0] ; keep 1 element in allfiles to feed to sofast_region_plotter.pro + keep track of offp/blur/eclipsed
	 		allfiles.quality='offpointed'
			allfiles.bluriness='blur'
			allfiles_notblur = allfiles
			allfiles_noteclipsed = allfiles
				
		ENDELSE
	
	ENDIF ELSE BEGIN ; IF n_not_offpointed gt 0 THEN BEGIN
	 	notification = '!! ALL INPUT IMAGES ARE OFFPOINTED !!'
	 	print, notification
	 		allfiles = allfiles_start[0] ; keep 1 element in allfiles to feed to sofast_region_plotter.pro + keep track of offp/blur/eclipsed
	 		indexallfiles = indexallfiles_start[0] ; keep 1 element in allfiles to feed to sofast_region_plotter.pro + keep track of offp/blur/eclipsed
			allfiles.quality = 'offpointed'
			allfiles_notoffpointed = allfiles
			allfiles_notblur = allfiles
			allfiles_noteclipsed = allfiles	
				
	ENDELSE
	
	
	allfiles.pixelresolution_thisrun = abs(indexallfiles[0].CDELT1) ; pixel resolution in arcseconds
	allfiles.b0_scenter_HGlatitude_thisrun = indexallfiles[0].HGLT_OBS  ; s/c heliographical latitude in degrees (not yet in radians)
	allfiles.rsun_thisrun = indexallfiles[0].RSUN_ARC ; solar radius at the time of observation in arcseconds
	
	
	; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX 
	 
	; KEEP TRACK OF BAD FILES OFFPOINTED / BLUR / ECLIPSED 
	
	openw, lun3, eventdir+'SoFAST_about_good_bad_files_considered_for_eventmovie_'+begindate+'.txt', /get_lun, /append 
	  	printf, lun3, ':Issued: '+systime()
	   	printf, lun3, ':Product: SoFAST catalogue (http://www.sidc.be/sofast)'
	   	printf, lun3, '#----------------------------------------------------------------------'
	   	printf, lun3, '# Instrument: SWAP| Detector: CMOS APS 1024 x 1024'
	   	printf, lun3, '# Flare-threshold : 2 | Rebinsize : 16 | Maxhits : 4 | Offset : 65'
	   	printf, lun3, '# Modus : (1) SW service <!--(2) Onboard (rebinfirst)-->'
	   	printf, lun3, '#' 
	   	printf, lun3, '  first SWAP image this run before preprocessing SWAP data: '+first_SWAP_thisrun_start
	   	printf, lun3, '  last  SWAP image this run before preprocessing SWAP data: '+last_SWAP_thisrun_start
	   	printf, lun3, '#'   
	   	printf, lun3, '#' 		
		printf, lun3, '    '
		printf, lun3, notification
		printf, lun3, '    '
		IF note_offp ne '    ' THEN BEGIN
			printf, lun3, note_offp
		ENDIF
		IF note_blur ne '    ' THEN BEGIN
			printf, lun3, note_blur
		ENDIF
		IF note_eclipse ne '    ' THEN BEGIN
			printf, lun3, note_eclipse
		ENDIF
		
	close, lun3
	free_lun, lun3	
	
	; nfiles_start = n_elements(allfiles_start)
	; print, 'nfiles_start = ', nfiles_start
	
	w_notoffpointed = where(allfiles_start.quality eq 'not-offpointed', n_notoffpointed)
	w_offpointed = where(allfiles_start.quality eq 'offpointed', n_offpointed) 
	 
	 
	IF n_offpointed gt 0 THEN BEGIN
	 	allfiles_offpointed = allfiles_start[w_offpointed]
	 	
	   	openw, lun3, eventdir+'SoFAST_about_good_bad_files_considered_for_eventmovie_'+begindate+'.txt', /get_lun, /append 
		printf, lun3, 'ALL FILES THAT ARE OFFPOINTED (BAD):'
		printf, lun3, '   '
		printf, lun3, allfiles_offpointed.url
		printf, lun3, '   '
		printf, lun3, '   '
		
		close, lun3
		free_lun, lun3	
	 ENDIF ;   IF n_offpointed gt 0 THEN BEGIN
	
	
	; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX 
	; BLURINESS BEING CHECKED AFTER OFFPOINT-CHECK:
	
	w_notblur = where(allfiles_notoffpointed.bluriness eq 'notblur', n_notblur)
	w_blur = where(allfiles_notoffpointed.bluriness eq 'blur', n_blur) 
	 
	IF n_notoffpointed gt 0 and n_blur gt 0 THEN BEGIN
		allfiles_blur = allfiles_notoffpointed[w_blur]
	 	
	 	openw, lun3, eventdir+'SoFAST_about_good_bad_files_considered_for_eventmovie_'+begindate+'.txt', /get_lun, /append 
			
		printf, lun3, 'ALL NOT_OFFPOINTED FILES THAT ARE BLUR (BAD):'
		printf, lun3, '   '
		printf, lun3, allfiles_blur.url
		printf, lun3, '   '
		printf, lun3, '   '
		
		close, lun3
		free_lun, lun3	
	ENDIF ;   IF n_offpointed gt 0 THEN BEGIN
	
	
	; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX 
	; ECLIPSE BEING CHECKED AFTER BLURINESS-CHECK:
	
	w_noteclipsed = where(allfiles_notblur.eclipse eq 'noteclipsed', n_noteclipsed)
	w_eclipsed = where(allfiles_notblur.eclipse eq 'eclipsed', n_eclipsed) 
	 
	IF n_notoffpointed gt 0 and n_notblur gt 0 and n_eclipsed gt 0 THEN BEGIN
	 	allfiles_eclipsed = allfiles_notblur[w_eclipsed]
	 	
	 	openw, lun3, eventdir+'SoFAST_about_good_bad_files_considered_for_eventmovie_'+begindate+'.txt', /get_lun, /append 
			
		printf, lun3, 'ALL NOT_OFFPOINTED & NOT_BLUR FILES THAT ARE ECLIPSED (BAD):'
		printf, lun3, '   '
		printf, lun3, allfiles_eclipsed.url
		printf, lun3, '   '
		printf, lun3, '   '
		
		close, lun3
		free_lun, lun3	
		
		IF n_eclipsed gt 4 THEN BEGIN ; we wouldn't give this notification for only 4 images
			 eclipse_notification = 'PROBA2 is currently in eclipse season.  SoFAST detections might be affected.'
		ENDIF
		
	 ENDIF ;   IF n_offpointed gt 0 THEN BEGIN
	
	
	; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX 
	; CREATE EVENTMOVIE 
	
	nimages = n_elements(allfiles)
	eventmovie = bytarr(rebinsize, rebinsize, nimages)   	;  output   containing significance level (0-5) of event detection 
		 														; (BYTE = values up to 255, requires less memory than e.g. int) 
	
	IF n_notoffpointed gt 0 and n_notblur gt 0 and n_noteclipsed gt 0 THEN BEGIN ; (IF nimages gt 1)

		 print, '# valuable (not offpointed, not blur, not eclipsed) SWAP images is ', nimages
		 nr_good_images = nimages
		 
		 images = intarr(rebinsize,rebinsize,nimages)
		 max_array_allmacropixels = fltarr(rebinsize*rebinsize, nimages)
		 min_array_allmacropixels = fltarr(rebinsize*rebinsize, nimages)
	
		; IF WORKING WITH SIMPLE REBIN:
		; eventmovie = bytarr(rebinsize, rebinsize, nimages)   	;  output   containing significance level (0-5) of event detection 
		 														; (BYTE = values up to 255, requires less memory than e.g. int)
			
		 FOR i=0, nimages-1 DO BEGIN
		 	print, nimages-i
	
		 	a = readfits(allfiles[i].url) ; now reading DATA ONLY 	; ONLY NECESSARY FOR CREATING "IMAGES", i.e. FOR KNOWING MAX_INT_REBINNED_IMG
			print, 'sofast_make_eventmovie: readfits allfiles for creating rebinned images '+strtrim(i,2)
		 	images[*,*,i] = rebin(a, rebinsize,rebinsize) ; images is NOT used for searching sister images or making eventmovie.  Only for avg_int_rebinned_img.
		 	allfiles[i].max_int_rebinned_img = max(images[*,*,i])	 	
		 	diff = min(abs(allfiles[i].obstime_n - allfiles.obstime_n - timedif), minpos) ; obstime_n = obstime in seconds; find sister image based on diff in obstime, where we search the minimum difference.  NOTE min() takes minimum of an ARRAY (allfiles[i].obstime_n - allfiles.obstime_n).  min[] takes minimum of given VALUES.
		 	
		 	; minpos is position of found minimum.
		 	
			IF diff le timetol THEN BEGIN	 	
			
				IF allfiles[i].quality ne 'offpointed' THEN BEGIN 	
			 	
			 		IF allfiles[minpos].quality ne 'offpointed' THEN BEGIN
			 			allfiles[i].sister = allfiles[minpos].url ; for all images where .sister is 'none', the sisterurl will be(come) its own url (so diff_im is 0)
			 			allfiles[i].sisterurl = allfiles[minpos].url
			 		
			 		ENDIF ELSE BEGIN
					allfiles[i].sisterurl = allfiles[i].url ; make sure difference a-b is going to be zero in case of images of which sister file is offpointed
															; since offpointed images are excluded this is actually not necessary anymore
					ENDELSE
			
				ENDIF ELSE BEGIN
				allfiles[i].sisterurl = allfiles[i].url ; make sure difference a-b is going to be zero in case of image which is offpointed.
														; since offpointed images are excluded this is actually not necessary anymore
				ENDELSE
				
			ENDIF ELSE BEGIN ; if diff greater than timetol
			allfiles[i].sisterurl = allfiles[i].url ; make sure difference a-b is going to be zero in case of images without a sister-image.
			ENDELSE
			
		
		ENDFOR
		; note: eventmovie = 0 where an image has no sister image
	
	
		FOR j=0, nimages-1 DO BEGIN
			print, nimages-j 
			a = readfits(allfiles[j].url)
			b = readfits(allfiles[j].sisterurl)
			print, 'sofast_make_eventmovie: readfits allfiles a and b for calculating diff and creating eventmovie '+strtrim(j,2)
		
	
			; THE USUAL, WITH SIMPLE REBIN	
			eventmovie[*,*,j] = (rebin(abs(a - b) - offset > 0.1, rebinsize, rebinsize) <255) ;  THE USUAL !!!  ; <255 since eventmovie is bytarr, but i don't expect >25
	
	
			; SAVING MAX AND MIN INTENSITY PER REGION BEFORE REBINNING (!!!!)
			; remember 	 max_array_allmacropixels = fltarr(rebinsize*rebinsize, nimages)  = 2D
			counter_max=0
			FOR x=0, (rebinsize-1) DO BEGIN
				FOR y=0, (rebinsize-1) DO BEGIN
	
				max_array_allmacropixels[counter_max,j]=max(a[x*xwidth:x*xwidth+(xwidth-1), y*ywidth:y*ywidth+(ywidth-1)])
			
				counter_max=counter_max+1 ; will go from 0 t.e.m. 255
			
				ENDFOR
			ENDFOR
	
			counter_min=0	
			FOR x=0, (rebinsize-1) DO BEGIN
				FOR y=0, (rebinsize-1) DO BEGIN
				min_array_allmacropixels[counter_min,j]=min(a[x*xwidth:x*xwidth+(xwidth-1), y*ywidth:y*ywidth+(ywidth-1)])
			
				counter_min=counter_min+1 ; will go from 0 t.e.m. 255
				ENDFOR
			ENDFOR
		
		ENDFOR
	
	
		counter_max = 0
		FOR x=0, (rebinsize-1) DO BEGIN
			FOR y=0, (rebinsize-1) DO BEGIN
			timeline_maxima_thismacropixel = max_array_allmacropixels[counter_max,*]
			save, filename = savdir+'timeline_maxima_thismacropixel_X'+strtrim(x,2)+'_Y'+strtrim(y,2)+'.sav', timeline_maxima_thismacropixel
			counter_max = counter_max + 1
			ENDFOR
		ENDFOR
	
	
		counter_min = 0
		FOR x=0, (rebinsize-1) DO BEGIN
			FOR y=0, (rebinsize-1) DO BEGIN
			timeline_minima_thismacropixel = min_array_allmacropixels[counter_min,*]
			save, filename = savdir+'timeline_minima_thismacropixel_X'+strtrim(x,2)+'_Y'+strtrim(y,2)+'.sav', timeline_minima_thismacropixel
			counter_min = counter_min + 1		
			ENDFOR
		ENDFOR
	
		
		
		; ADDED 16052011
		FOR x=0,(rebinsize-1) DO BEGIN
			FOR y=0,(rebinsize-1) DO BEGIN
			macropixel_int = images[x,y,*] ; Macropixel intensity of this macropixel during "this run"
			;stop ; print, x, y ; tt=images[*,*,*] ; plot_image, tt[*,*,0] ; tt[x,y,0]=200 ; plot_image, tt
			save, filename = savdir+'macropixel_int_X'+strtrim(x,2)+'_Y'+strtrim(y,2)+'.sav', macropixel_int
			ENDFOR
		ENDFOR
			
		;save, filename = savdir+'rebinned_images.sav', images ; 	images[*,*,i] = rebin(a, rebinsize,rebinsize)
		;save, filename = savdir+'eventmovie.sav', eventmovie
	
	
		;allgoodfiles_considered_for_eventmovie = allfiles[where (allfiles.sister ne 'none')]
		openw, lun3, eventdir+'SoFAST_about_good_bad_files_considered_for_eventmovie_'+begindate+'.txt', /get_lun, /append 
			printf, lun3, '   '
			printf, lun3, 'ALL SoFAST-QUALIFIED SWAP IMAGES (not offpointed/blur/eclipsed), WITH GIVEN THEIR SISTER-IMAGE:'
			printf, lun3, '   '
			printf, lun3, '   '
		close, lun3	
		free_lun, lun3
	
		FOR j=0, nimages-1 DO BEGIN
			openw, lun3, eventdir+'SoFAST_about_good_bad_files_considered_for_eventmovie_'+begindate+'.txt', /get_lun, /append
				print, 'In sofast_sofast_make_eventmovie.pro line 441 lun3 = ', lun3 ; KB 13112014 added for test "all logical units are currently in use"
				printf, lun3, allfiles[j].url
				printf, lun3, 'SISTER_URL: ', allfiles[j].sisterurl
				printf, lun3, '   ' ; white line
			close, lun3
			free_lun, lun3	
		ENDFOR
	
	ENDIF ELSE BEGIN  ;  IF n_notoffpointed gt 0 and n_notblur gt 0 and n_noteclipsed gt 0 THEN BEGIN  ;(if nimages gt 1)
		print, notification
		nr_good_images = 0

	ENDELSE

ENDIF ELSE BEGIN ; IF nfiles_start gt 1 THEN BEGIN  ; IF NO IMAGES THEN ALLFILES = 0 (n_elements=1)

nr_good_images = nfiles_start ; 1

print, 'There is no SWAP data available for this run.'

openw, lun3, eventdir+'SoFAST_about_good_bad_files_considered_for_eventmovie_'+begindate+'.txt', /get_lun, /append 
	  	printf, lun3, ':Issued: '+systime()
	   	printf, lun3, ':Product: SoFAST catalogue (http://www.sidc.be/sofast)'
	   	printf, lun3, '#----------------------------------------------------------------------'
	   	printf, lun3, '# Instrument: SWAP| Detector: CMOS APS 1024 x 1024'
	   	printf, lun3, '# Flare-threshold : 2 | Rebinsize : 16 | Maxhits : 4 | Offset : 65'
	   	printf, lun3, '# Modus : (1) SW service <!--(2) Onboard (rebinfirst)-->'
	   	printf, lun3, '#' 
	   	printf, lun3, '  first SWAP image this run before preprocessing SWAP data: n.a. (no SWAP data)'
	   	printf, lun3, '  last  SWAP image this run before preprocessing SWAP data: n.a. (no SWAP data)'
	   	printf, lun3, '#'   
	   	printf, lun3, '#' 		
		printf, lun3, '    '
		printf, lun3, 'There is no SWAP data available for this run'
close, lun3
free_lun, lun3

ENDELSE




return, eventmovie ; 3D array, 12min-differences of rebinned images.  Value zero (in case of offpointed and) in case of no sister (or being an offpointed sister image).  Values 0-255.


END
