;======================== header ===============================================
;+
; NAME:
;       sofast_P2_GET_DAILY_EVENTS_FROM_NOAA
;
; !! Most easy working: Make sure GOES EVENT FILES OLDER THAN 2 MONTHS FROM RUNTIME ARE IN "GOESEVENTS DIR" !!
; !! The necessary zip files with event files can be found at http://www.swpc.noaa.gov/ftpdir/warehouse/ !!
;
; PURPOSE:
;		Is called by sofast_p2_get_goes_flares
;       Downloads and parses the Solar Event files from NOAA/SWPC, 
;		returns the result as an element of the handy structure array with 1 element per event (flare).
;
; INPUT: 
;		mydate = '20110104'
;
; PROCEDURES USED:
;		wget
;
; RESTORED SAV-files:
;		/
;
; SAVED SAV-files:
;		/
;
; HISTORY:  
;		2011 Jan 4, DAB, first version 
;		2012 Dec 12, KB, update to final SoFAST version 
;
; wget -r -l1 --no-parent -nH -Aevents.txt http://www.swpc.noaa.gov/ftpdir/indices/events/
;-
;======================== end header ===========================================

FUNCTION sofast_p2_get_daily_events_from_noaa, mydate, goeseventdir=goeseventdir ; mydate = (thisyear+'-'+thismonth+'-'+thisday)

  reference_julday = julday(1,1,2010)


 myyear  = strmid(mydate,0,4)
 mymonth = strmid(mydate, 5,2)
 myday	 = strmid(mydate, 8,2)

  	;local_dir  = '/Users/katrien/PROBA2/variabiliteit_analyse/DATA/temp_swaplocal/input/GOESFITS/'
  	local_dir=goeseventdir ; containing GOES event txt files older than 2 months
  	; remote_dir = 'http://www.swpc.noaa.gov/ftpdir/indices/events/' ; stores last 2 months of 20121101events.txt files
	remote_dir = 'ftp://ftp.swpc.noaa.gov/pub/indices/events/' ; KB UPDATE 20150130 since noaa changed their urls (09) dec 2014

; NEXT FOLLOWING IS UNCOMMENTED SINCE EVENTFILES OLDER THAN 2 MONTHS SHOULD BE STORED IN GOESEVENTS DIR
;  	if myyear eq '2010' then remote_dir = 'http://www.swpc.noaa.gov/ftpdir/warehouse/2010/2010_events/' ; NO LONGER EXISTING
;  	if myyear lt '2010' then begin
;  		print, "Please download Event file manually from http://www.swpc.noaa.gov/ftpdir/warehouse/"
;  		exit
;  	endif
 
 
	swpc_filename  		= myyear+mymonth+myday	 +'events.txt'  
	swpc_remote_file 	= remote_dir +swpc_filename
	swpc_local_file 	= local_dir	 +swpc_filename


 ; Download NOAA/SWPC event file ONLINE IF IT IS NOT AVAILABLE LOCALLY

	if not(file_exist(swpc_local_file)) then spawn, 'wget '+swpc_remote_file+  ' --output-document='+swpc_local_file
 

 ; Define flare structure 
  dummy = {date:'20101010',xra_beg:'0100', xra_max:'0200', xra_end:'0300', xra_obs:'G15', xra_frq:'1-8A',xra_mag:'B1.1', xra_reg:'xxxx',  $
  	date_n:2455323l , $  ; julian day
	xra_beg_n:0l, $ ; numerical equivalent of xra_beg in sec since reference julday
  	xra_max_n:0l, $ ; numerical equivalent of xra_beg in sec since reference julday
  	xra_end_n:0l, $ ; numerical equivalent of xra_beg in sec since reference julday
    xra_mag_n:0.0 } ; numerical equivalent of xra_mag in Watts/m^2
 

 
 ; Read content from local NOAA/SWPC event file
 
 	OPENR, io_unit, swpc_local_file, /GET_LUN  
  	
	; Read event_lines
	line = '' & event_lines=''
	WHILE ~ EOF(io_unit) DO BEGIN  
	   READF, io_unit, line
	   event_lines=[event_lines, line]  
	ENDWHILE  
	if n_elements(event_lines) gt 1 then event_lines=event_lines[1:*] else begin
		print, "Error reading file "+swpc_local_file
		exit
	endelse
	close, io_unit
	free_lun, io_unit
	
	; extract relevant content from event_lines
	
	events=dummy
	for i=0, n_elements(event_lines)-1 do begin
		line = event_lines[i]
		good_line =  strmid(line, 0,1) ne ':' and strmid(line, 0,1) ne '#' and line ne '' and line ne 'NO EVENT REPORTS.'
		if good_line then begin 
			splitline = strsplit(strmid(line,10,100), ' ',/extract)
			if splitline[5] eq 'XRA' then begin
				dummy.date 		=myyear+'-'+mymonth+'-'+myday
				dummy.xra_beg 	=splitline[0]
				dummy.xra_max 	=splitline[1]
				dummy.xra_end 	=splitline[2]
				dummy.xra_obs 	=splitline[3]
				dummy.xra_frq 	=splitline[6]
				dummy.xra_mag 	=splitline[7]
				dummy.date_n        = julday(mymonth, myday, myyear)  
				dummy.xra_beg_n 	= (STRMID(splitline[0],0,2)*60l+STRMID(splitline[0],2,2))*60l  
				dummy.xra_max_n 	= (STRMID(splitline[1],0,2)*60l+STRMID(splitline[1],2,2))*60l  
				dummy.xra_end_n 	 =(STRMID(splitline[2],0,2)*60l+STRMID(splitline[2],2,2))*60l  
				t= strmid(splitline[7],0,1) ; temporary variable containing flare class
				dummy.xra_mag_n 	=  float(strmid(splitline[7],1,3))*((t eq 'B')*10.^(-7) + (t eq 'C')*10.^(-6)+(t eq 'M')*10.^(-5)+(t eq 'X')*10.^(-4))
							
				if n_elements(splitline) ge 10 then dummy.xra_reg 	=splitline[9]
				;
				events=[events, dummy]
			endif
		endif
	endfor
	nevents=n_elements(events)
	if nevents ge 2 then begin
		events=events[1:*] & nevents = nevents-1
		events.date_n    = events.date_n - reference_julday
		events.xra_beg_n = events.xra_beg_n + 86400l*events.date_n
		events.xra_max_n = events.xra_max_n + 86400l*events.date_n
		events.xra_end_n = events.xra_end_n + 86400l*events.date_n
		for i=0, nevents-1 do begin
			if events[i].xra_max_n lt events[i].xra_beg_n then events[i].xra_beg_n = events[i].xra_beg_n - 86400l
			if events[i].xra_end_n lt events[i].xra_max_n then events[i].xra_end_n = events[i].xra_end_n + 86400l
		endfor
	endif  else events = 0

	return, events	
END
