;======================== header ===============================================
;+
; NAME:
;       sofast_P2_GETSWAPFILENAMES 
;
; PURPOSE:
;		Is called by sofast.pro  (or sofast_swaplocal.pro or sofast_WGET_local.pro)
;       Gets all the available SWAP filenames for a certain time-period, from http://proba2.sidc.be or locally.
;		Creates a structure n_elements = n_filenames, tags like obstime, url, sisterurl, goesmatch, goestype, etc. STR ELEMENT PER IMAGE
;
; INPUT
;		begindate, enddate = '2011-01-04'
;		source = either 'web' or a local directory where the images are (inputdir)
;		savdir = where to save *.sav-files
;
; PROCEDURES USED:
;		sock_find
;
; RESTORED SAV-files:
;		/
;
; SAVED SAV-files
;		UNCOMMENTED: save, filename = savdir+'im_list.sav', im_list (CONTAINS im_list=the structure mentioned above)

; HISTORY:  
;		2012 Dec 12, KB, update to final SoFAST version 
;-
;======================== end header ===========================================

FUNCTION sofast_p2_getswapfilenames, begindate, enddate, source=source, savdir=savdir ; (source=inputdir)

  IF ~ keyword_set(source) THEN source='web'
  IF ~ file_exist(source) THEN source='web'
  
 ; configuration
	reference_julday = julday(1,1,2010)
	myserver=	'http://proba2.sidc.be'  ; matters for source='web' only
	mypath  =	'/swap/data/bsd/'		 ; matters for source='web' only
	prefix   = 'swap_lv1_'

 ; decipher input range
	beginyear  	= strmid(begindate, 0, 4)
	beginmonth 	= strmid(begindate, 5, 2)
	beginday   	= strmid(begindate, 8, 2)
	beginjul	= julday(beginmonth, beginday, beginyear)
		
	endyear   	= strmid(enddate, 0, 4)
	endmonth 	= strmid(enddate, 5, 2)
	endday   	= strmid(enddate, 8, 2)
	endjul 		= julday(endmonth, endday, endyear)

  ; prepare I/O variables	
	template= {$
		date:'2010-10-10', $   ; date yyyy-mm-dd, iso8601 complaint
		date_n: 2455341l , $         ; numerical value of date, julian day
		obstime: 000000l , $
		obstime_n: 100l,$          ; sec since begin of day
		url:'/2010/01/04/swap_lv1_20100104_170218.001.fits', $ ; SWAP filename
		quality:'not yet', $  ; whether or not the image is offpointed
		bluriness:'not yet', $  ; whether or not the image is blur
		eclipse:'not yet', $  ; whether or not the image is blur
		sister: 'none', $  ; whether or not the image HAS a sister image
		sisterurl: 'not yet', $ ; image +-12 minutes earlier.  every image should have an url here in the end.  Whether it really is a sisterurl, or its own.
		goesmatch: 'no GOES flare (so far)', $  ; whether this images matches with a GOES flare detection
		goesstarttime: 'n.a.', $  ; when resp GOESflare started
		goesendtime: 'n.a.', $  ; when resp GOESflare ended
		goestype: 'n.a.', $ ; GOES flare category
		goes_NOAA_region: 'n.a.', $ ; GOES flare region (NOAA AR)
		;swavint: 'value swavint' }  ; we will put value of swavint here
		max_int_rebinned_img: 'not yet known', $
		n_order: '000000', $
		pixelresolution_thisrun: 0.0, $    ; pixel resolution in arcseconds
		b0_scenter_HGlatitude_thisrun: 0.0, $    ; s/c heliographical latitude in degrees (not yet in radians)
		rsun_thisrun: 0.0, $     ; solar radius at the time of observation in arcseconds
		beginjul: beginjul, $    
		endjul: endjul }   
	im_list=template

  ; find the files for every day
    FOR thisjul = beginjul, endjul DO BEGIN ;loop all dates, creating structure PER DAY images_of_today, which then is placed in array of structures (im_list)
		caldat, thisjul, thismonth, thisday, thisyear
		thisyear = strtrim(thisyear,2)
		thismonth= strmid(strtrim(thismonth+100,2),1,2)
		thisday  = strmid(strtrim(thisday+100,2),1,2)

		if (source eq 'web') then $
					files=sock_find(myserver,'*.fits', path=mypath+thisyear+'/'+thismonth+'/'+thisday) $ ; files = list of filenames
							 else $
					spawn, 'ls '+source+'/'+thisyear+'/'+thismonth+'/'+thisday+'/'+prefix+thisyear+thismonth+thisday+'*.fits', files
		if files[0] ne '' then begin
			images_of_today = replicate(template, n_elements(files))
			images_of_today.date   = thisyear+'-'+thismonth+'-'+thisday
			images_of_today.date_n = thisjul
			images_of_today.url    = files ; filenames in tag url
			im_list=[im_list, images_of_today] 	
		endif
		
	ENDFOR

   ; do timing calculations all at once
    if n_elements(im_list) ge 2 then begin
	    im_list=im_list[1:*] 
	    im_list.date_n      = im_list.date_n - reference_julday ; we want smaller numbers so simply subtract a reference day (first of interest)
	    hhmmss   			= strmid(im_list.url,strpos(im_list[0].url,prefix)+18,6) ; applies to every element of structure im_list
		im_hrs	 			= float(strmid(hhmmss,0,2))
		im_min		 		= float(strmid(hhmmss,2,2))
		im_sec		 		= float(strmid(hhmmss,4,2))
		im_list.obstime		= hhmmss
		im_list.obstime_n   = (im_hrs*60l +im_min)*60l +im_sec  + im_list.date_n*86400l;  sec since ref_julday
		;im_list.quality		= 'unknown'
	endif else im_list = 0

;stop ; help, im_list

	;save, filename = savdir+'im_list.sav', im_list


	 ; prepare to exit
	 
;stop	 
	 
	return, im_list	
	
END